@@ -1,4 +1,8 @@
 # -*- coding: utf-8 -*-
+
+"""将快代理所有api接口封装到Client
+"""
+
 import json
 import time
 import requests
@@ -13,8 +17,8 @@ class Client:
         self.auth = auth
 
     def get_order_expire_time(self, sign_type="simple"):
-        """ 获取订单到期时间, 强制签名验证
-            :return 订单过期时间字符串
+        """获取订单到期时间, 强制签名验证
+           :return 订单过期时间字符串
         """
 
         endpoint = EndPoint.GetOrderExpireTime.value
@@ -26,8 +30,8 @@ class Client:
         return res
 
     def get_ip_whitelist(self, sign_type="simple"):
-        """ 获取订单的ip白名单, 强制签名验证
-            :return ip白名单列表
+        """获取订单的ip白名单, 强制签名验证
+           :return ip白名单列表
         """
         endpoint = EndPoint.GetIpWhitelist.value
         params = self._get_params(endpoint, sign_type=sign_type)
@@ -36,12 +40,11 @@ class Client:
             return res['data']['ipwhitelist']
         return res
 
-
     def set_ip_whitelist(self, iplist=None, sign_type="simple"):
-        """ 设置订单的ip白名单, 强制签名验证
-            :param iplist参数类型为 str 或 list 或 tuple
-                   如果为字符串则ip之间用逗号隔开
-            :return 成功则返回True, 否则抛出异常
+        """设置订单的ip白名单, 强制签名验证
+           :param iplist参数类型为 str 或 list 或 tuple
+                  如果为字符串则ip之间用逗号隔开
+           :return 成功则返回True, 否则抛出异常
         """
 
         if iplist is None:
@@ -56,37 +59,50 @@ class Client:
         return True
 
     def tps_current_ip(self, sign_type="simple"):
-        """
-        仅支持支持换IP周期>=1分钟的隧道代理订单
-
-        获取隧道当前的IP，默认“simple”鉴权
-        :param sign_type:默认simple
-        :return:返回ip地址。
+        """仅支持支持换IP周期>=1分钟的隧道代理订单
+           获取隧道当前的IP，默认“simple”鉴权
+           :param sign_type:默认simple
+           :return:返回ip地址。
         """
         endpoint = EndPoint.TpsCurrentIp.value
         params = self._get_params(endpoint,sign_type=sign_type)
         res = self._get_base_res("GET",endpoint,params)
         return res['data']['current_ip']
 
-
     def change_tps_ip(self, sign_type="simple"):
-        """
-         仅支持支持换IP周期>=1分钟的隧道代理订单
-        :param sign_type: 默认simple
-        :return: 返回新的IP地址
+        """仅支持支持换IP周期>=1分钟的隧道代理订单
+           :param sign_type: 默认simple
+           :return: 返回新的IP地址
         """
         endpoint = EndPoint.ChangeTpsIp.value
         params = self._get_params(endpoint,sign_type=sign_type)
         res = self._get_base_res("GET",endpoint,params)
         return res['data']['new_ip']
 
+    def get_dps_valid_time(self, proxy=None, sign_type="simple", **kwargs):
+        """获取私密代理ip有效时间
+           :param proxy: 私密代理列表, 格式： IP:PORT, eg: 113.120.61.166:22989,122.4.44.132:21808
+           :param sign_type: 认证方式
+           :return: 返回data部分, 格式为由'proxy: seconds(剩余秒数)'组成的列表
+        """
+        if not proxy:
+            raise KdlNameError("miss param: proxy")
+        if not (isinstance(proxy, list) or isinstance(proxy, tuple) or isinstance(proxy, str)):
+            raise KdlTypeError("proxy should be a instance of list or tuple or str")
+        if isinstance(proxy, list) or isinstance(proxy, tuple):
+            proxy = ','.join(proxy)
+        endpoint = EndPoint.GetDpsValidTime.value
+        params = self._get_params(endpoint, proxy=proxy, sign_type=sign_type)
+        res = self._get_base_res("GET", endpoint, params)
+        if isinstance(res, dict):
+            return res['data']
+        return res
 
     def get_dps(self, num=None, sign_type="simple", **kwargs):
-        """
-            获取私密代理, 默认"simple"鉴权
-            :param num: 提取数量, int类型
-            :param kwargs: 其他关键字参数，具体有那些参数请查看帮助中心api说明
-            :return 若为json格式, 则返回data中proxy_list部分, 即proxy列表, 否则原样返回
+        """获取私密代理, 默认"simple"鉴权
+           :param num: 提取数量, int类型
+           :param kwargs: 其他关键字参数，具体有那些参数请查看帮助中心api说明
+           :return 若为json格式, 则返回data中proxy_list部分, 即proxy列表, 否则原样返回
         """
         if num is None:
             raise KdlNameError("miss param: num")
@@ -100,9 +116,8 @@ class Client:
         return res
 
     def check_dps_valid(self, proxy=None, sign_type="simple", **kwargs):
-        """
-            检测私密代理有效性, 强制签名验证
-            :return 返回data部分, 格式为由'proxy: True/False'组成的dict
+        """检测私密代理有效性, 强制签名验证
+           :return 返回data部分, 格式为由'proxy: True/False'组成的dict
         """
         if not proxy:
             raise KdlNameError("miss param: proxy")
@@ -119,10 +134,9 @@ class Client:
         return res
 
     def get_ip_balance(self, sign_type="simple"):
-        """
-            获取计数版订单ip余额, 强制签名验证,
-            此接口只对按量付费订单和包年包月的集中提取型订单有效
-            :return 返回data中的balance字段, int类型
+        """获取计数版订单ip余额, 强制签名验证,
+           此接口只对按量付费订单和包年包月的集中提取型订单有效
+           :return 返回data中的balance字段, int类型
         """
         endpoint = EndPoint.GetIpBalance.value
         params = self._get_params(endpoint, sign_type=sign_type)
@@ -132,10 +146,10 @@ class Client:
         return res
 
     def get_kps(self, num=None, sign_type="simple", **kwargs):
-        """ 获取独享代理, 默认"simple"鉴权
-            :param num: 提取数量, sign_type: 鉴权方式
-            :param kwargs: 其他关键字参数，具体有那些参数请查看帮助中心api说明
-            :return 若为json格式, 则返回data中proxy_list部分, 即proxy列表, 否则原样返回
+        """获取独享代理, 默认"simple"鉴权
+           :param num: 提取数量, sign_type: 鉴权方式
+           :param kwargs: 其他关键字参数，具体有那些参数请查看帮助中心api说明
+           :return 若为json格式, 则返回data中proxy_list部分, 即proxy列表, 否则原样返回
         """
         if num is None:
             raise KdlNameError("miss param: num")
@@ -149,10 +163,10 @@ class Client:
         return res
 
     def get_proxy(self, num=None, order_level=OpsOrderLevel.NORMAL, sign_type="simple", **kwargs):
-        """ 获取开放代理, 默认不需要鉴权
-            :param num: 提取数量, sign_type: 鉴权方式, order_level: 开放代理订单类型
-            :param kwargs: 其他关键字参数，具体有那些参数请查看帮助中心api说明
-            :return 若为json格式, 则返回data中proxy_list部分, 即proxy列表, 否则原样返回
+        """获取开放代理, 默认不需要鉴权
+           :param num: 提取数量, sign_type: 鉴权方式, order_level: 开放代理订单类型
+           :param kwargs: 其他关键字参数，具体有那些参数请查看帮助中心api说明
+           :return 若为json格式, 则返回data中proxy_list部分, 即proxy列表, 否则原样返回
         """
         if num is None:
             raise KdlNameError("miss param: num")
@@ -171,9 +185,8 @@ class Client:
         return res
 
     def check_ops_valid(self, proxy=None, sign_type="simple", **kwargs):
-        """
-            检测开放代理有效性, 强制签名验证
-            :return 返回data部分, 格式为由'proxy: True/False'组成的列表
+        """检测开放代理有效性, 强制签名验证
+           :return 返回data部分, 格式为由'proxy: True/False'组成的列表
         """
         if not proxy:
             raise KdlNameError("miss param: proxy")
@@ -189,7 +202,7 @@ class Client:
         return res
 
     def _get_params(self, endpoint, **kwargs):
-        """ 构造请求参数 """
+        """构造请求参数"""
         params = dict(orderid=self.auth.orderId)
         params.update(kwargs)
 
@@ -216,10 +229,10 @@ class Client:
         return params
 
     def _get_base_res(self, method, endpoint, params):
-        """ 处理基础请求,
-            若响应为json格式则返回请求结果dict
-            否则直接返回原格式 """
-
+        """处理基础请求,
+           若响应为json格式则返回请求结果dict
+           否则直接返回原格式
+        """
         try:
             r = None
             if method == "GET":
