@@ -1,5 +1,8 @@
 # -*- coding: utf-8 -*-
 
+"""枚举各个api的主机+路径
+"""
+
 from enum import Enum, unique
 
 
@@ -17,6 +20,7 @@ class EndPoint(Enum):
     CheckDpsValid = "dps.kdlapi.com/api/checkdpsvalid"
     CheckOpsValid = "dev.kdlapi.com/api/checkopsvalid"
     GetIpBalance = "dps.kdlapi.com/api/getipbalance"
+    GetDpsValidTime = "dps.kdlapi.com/api/getdpsvalidtime"
     TpsCurrentIp = "tps.kdlapi.com/api/tpscurrentip" # 获取当前隧道代理IP
     ChangeTpsIp = "tps.kdlapi.com/api/changetpsip" # 更改当前隧道代理IP
 
